# AccountingCodeType

If you want to create multiple accounting codes of the type `AccountsReceivable`, you need to have [Invoice Item Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/C_Invoice_Item_Settlement) enabled and contact [Zuora Global Support](http://support.zuora.com) to access the Multiple AR Accounting Codes feature. Note that `On-Account Receivable` is only available if you enable the Invoice Settlement feature.

## Enum

* `ACCOUNTSRECEIVABLE` (value: `'AccountsReceivable'`)

* `ONACCOUNTRECEIVABLE` (value: `'OnAccountReceivable'`)

* `CASH` (value: `'Cash'`)

* `OTHERASSETS` (value: `'OtherAssets'`)

* `CUSTOMERCASHONACCOUNT` (value: `'CustomerCashOnAccount'`)

* `DEFERREDREVENUE` (value: `'DeferredRevenue'`)

* `SALESTAXPAYABLE` (value: `'SalesTaxPayable'`)

* `OTHERLIABILITIES` (value: `'OtherLiabilities'`)

* `SALESREVENUE` (value: `'SalesRevenue'`)

* `SALESDISCOUNTS` (value: `'SalesDiscounts'`)

* `OTHERREVENUE` (value: `'OtherRevenue'`)

* `OTHEREQUITY` (value: `'OtherEquity'`)

* `BADDEBT` (value: `'BadDebt'`)

* `OTHEREXPENSES` (value: `'OtherExpenses'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


